@@ -7,8 +7,6 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id$
-;;;;
 ;;;; This file, part of KMRCL, is Copyright (c) 2002 by Kevin M. Rosenberg
 ;;;;
 ;;;; KMRCL users are granted the rights to distribute and use this software
@@ -73,11 +71,14 @@
             it
             nil)))))
 
-(defun flatten (lis)
-  (cond ((atom lis) lis)
-        ((listp (car lis))
-         (append (flatten (car lis)) (flatten (cdr lis))))
-        (t (append (list (car lis)) (flatten (cdr lis))))))
+(defun flatten (tree)
+  (let ((result '()))
+    (labels ((scan (item)
+               (if (consp item)
+                   (map nil #'scan item)
+                   (push item result))))
+      (scan tree))
+    (nreverse result)))
 
 ;;; Keyword functions
 
