@@ -7,9 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id$
-;;;;
-;;;; This file, part of KMRCL, is Copyright (c) 2002-2006 by Kevin M. Rosenberg
+;;;; This file, part of KMRCL, is Copyright (c) 2002-2010 by Kevin M. Rosenberg
 ;;;;
 ;;;; KMRCL users are granted the rights to distribute and use this software
 ;;;; as governed by the terms of the Lisp Lesser GNU Public License
@@ -114,6 +112,15 @@
    #:+datetime-number-strings+
    #:utc-offset
    #:copy-binary-stream
+   #:def-unsigned-int-io
+   #:make-unsigned-int-io-fn
+   #:read-uint2-le #:read-uint2-be #:write-uint2-le #:write-uint2-be
+   #:read-uint3-le #:read-uint3-be #:write-uint3-le #:write-uint3-be
+   #:read-uint4-le #:read-uint4-be #:write-uint4-le #:write-uint4-be
+   #:read-uint5-le #:read-uint5-be #:write-uint5-le #:write-uint5-be
+   #:read-uint6-le #:read-uint6-be #:write-uint6-le #:write-uint6-be
+   #:read-uint7-le #:read-uint7-be #:write-uint7-le #:write-uint7-be
+   #:read-uint8-le #:read-uint8-be #:write-uint8-le #:write-uint8-be
 
    ;; impl.lisp
    #:probe-directory
@@ -319,4 +326,15 @@
    ;; signals.lisp
    #:set-signal-handler
    #:remove-signal-handler
+
+   ;; btree.lisp
+   #:sorted-vector-find
+   #:string-tricmp
+   #:simple-string-tricmp
+   #:number-tricmp
+   #:complex-number-tricmp
+
+   ;; mop.lisp
+   #:short-arg-cesd
+   #:short-arg-dsdc
    ))
